package test;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Loescht alle bisherigen Daten und spielt Daten in korrekter Reihenfolge ein.
 * Funktioniert nur, wenn alle Tabellen angelegt sind. Man beachte, dass beim
 * Loeschen und Einfuegen Trigger bereits ausgefuehrt werden.
 */
public class Basisdaten {

    private static Connection con = null; // direkte DB-Verbindung
    private Statement s;

    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
        con = Verbindung.verbinden();
        datenLoeschen(con);
    }

    @AfterClass
    public static void tearDownAfterClass() throws Exception {
        Verbindung.verbindungTrennen(con);
    }

    @Before
    public void setUp() throws SQLException {
        s = con.createStatement();
        this.datenEinfuegen(s);
    }

    @After
    public void tearDown() throws SQLException {
        datenLoeschen(con);
        if (!s.isClosed()) {
            s.close();
        }
    }

    public void initialisieren(Connection con) throws Exception {
        datenLoeschen(con);

        try (Statement s = con.createStatement()) {
            this.s = s;
            this.datenEinfuegen(s);
            this.testInsert444();
            this.testInsert445();
            this.testInsert446();
            this.testInsert447();
            this.testInsert448();
            this.testInsert449();
            this.testInsert450();
        }
    }

    public static void datenLoeschen(Connection con1) throws SQLException {
        for (int i = 3; i > 0; i--) {
            con1.createStatement().executeUpdate("DELETE FROM Pruefung WHERE versuch =" + i);
        }
        con1.createStatement().executeUpdate("DELETE FROM Studierend");
        con1.createStatement().executeUpdate("DELETE FROM Modul");
    }

    public void datenEinfuegen(final Statement s1) throws SQLException {
        s1.executeUpdate("INSERT INTO Studierend VALUES (444,'Oleg')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (445,'Helga')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (446,'Olga')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (447,'Abdul')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (448,'Sila')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (449,'Sven')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (450,'Erik')");
        s1.executeUpdate("INSERT INTO Studierend VALUES (451,'Sarah')");
        s1.executeUpdate("INSERT INTO Modul VALUES (11,'Grundlagen Programmierung',1,10)");
        s1.executeUpdate("INSERT INTO Modul VALUES (12,'Grundlagen Mathematik',1,10)");
        s1.executeUpdate("INSERT INTO Modul VALUES (13,'Wissenschaftliches Arbeiten',1,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (14,'Elektrotechnische Grundlagen',1,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (21,'Fortgeschrittene Programmierung',2,10)");
        s1.executeUpdate("INSERT INTO Modul VALUES (22,'Mathematik fuer Informatik',2,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (23,'Kommunikationsnetze',2,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (24,'Physikalische Grundlagen',2,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (25,'Digitaltechnik',2,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (31,'Englisch',3,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (32,'OO Analyse und Design',3,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (33,'Mathematik fuer TI',3,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (34,'Algorithmen und Datenstrukturen',3,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (35,'Datenbanken',3,5)");
        s1.executeUpdate("INSERT INTO Modul VALUES (36,'Rechnerarchitektur',3,5)");
    }

    @Test
    public void testInsert450() throws SQLException {
        // endgueltig in 11 durchgefallen
        s.executeUpdate("INSERT INTO Pruefung VALUES (450,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (450,12,'2014-02-08',2,400)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (450,13,'2013-10-13',1,330)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (450,11,'2013-10-11',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (450,11,'2014-02-09',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (450,11,'2014-10-11',3,500)");
    }

    @Test
    public void testInsert449() throws SQLException {
        // nur wenige Pruefungen des ersten Semesters
        s.executeUpdate("INSERT INTO Pruefung VALUES (449,11,'2013-10-11',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (449,11,'2014-02-09',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (449,11,'2014-10-11',3,400)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (449,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (449,12,'2014-02-08',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (449,13,'2013-10-13',1,230)");
    }

    @Test
    public void testInsert448() throws SQLException {
        // alle Pruefungen gemacht und bestanden
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,11,'2013-10-11',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,12,'2014-02-08',2,330)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,13,'2013-10-13',1,230)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,14,'2013-10-14',1,370)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,21,'2014-02-03',1,100)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,22,'2014-02-04',1,200)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,23,'2013-02-05',1,170)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,24,'2014-02-06',1,330)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,25,'2014-02-07',1,270)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,31,'2014-10-11',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,32,'2014-10-12',1,100)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,33,'2014-10-13',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,34,'2014-10-14',1,230)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,35,'2014-10-15',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (448,36,'2014-10-16',1,230)");
    }

    @Test
    public void testInsert447() throws SQLException {
        // darf gerade nicht ins dritte Semester, da 5 CP fehlen
        // ist im dritten Versuch bei 12
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,11,'2013-10-11',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,12,'2014-02-08',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,13,'2013-10-13',1,100)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,14,'2013-10-14',1,200)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,21,'2014-02-03',1,270)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,23,'2014-02-05',1,170)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (447,24,'2014-02-06',1,230)");
    }

    @Test
    public void testInsert446() throws SQLException {
        // in zwei Modulen im dritten Versuch, zu wenig CP fuer das
        // dritte Semester
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,11,'2013-10-11',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,11,'2014-02-09',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,12,'2014-02-08',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,13,'2013-10-13',1,300)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,21,'2014-02-03',1,400)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,22,'2014-02-04',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (446,23,'2014-02-05',1,270)");
    }

    @Test
    public void testInsert445() throws SQLException {
        // darf gerade Pruefungen des dritten Semesters machen, ist in
        // einem Drittversuch
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,11,'2013-10-11',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,12,'2014-02-08',2,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,13,'2013-10-13',1,230)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,14,'2013-10-14',1,370)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,22,'2014-02-04',1,200)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,23,'2014-02-05',1,170)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,24,'2014-02-06',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (445,25,'2014-02-07',1,370)");
    }

    @Test
    public void testInsert444() throws SQLException {
        //darf alle Pruefungen machen, fehlt pro Semester mindestens eine
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,11,'2013-10-11',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,12,'2013-10-12',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,12,'2014-02-08',2,330)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,13,'2013-10-13',1,230)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,14,'2013-10-14',1,370)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,21,'2014-02-03',1,500)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,22,'2014-02-04',1,400)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,23,'2014-02-05',1,170)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,24,'2014-02-06',1,330)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,25,'2014-02-07',1,270)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,31,'2014-10-11',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,35,'2014-10-15',1,130)");
        s.executeUpdate("INSERT INTO Pruefung VALUES (444,36,'2014-10-16',1,230)");
    }
}
