package test;

import java.sql.Connection;
import java.sql.SQLException;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class TriggerBTest {

    private static Connection con = null; // direkte DB-Verbindung
    private Basisdaten basisdaten = new Basisdaten();

    @BeforeAll
    public static void setUpBeforeClass() throws Exception {
        con = Verbindung.verbinden();
    }

    @AfterAll
    public static void tearDownAfterClass() throws Exception {
        Verbindung.verbindungTrennen(con);
    }

    @BeforeEach
    public void setUp() throws Exception {
        basisdaten.initialisieren(con);
    }

    @Test
    public void testLetzePruefungenAendernOk1() {
        try {
            int anzahl = con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET note = 500 "
                            + "WHERE matnr=444 AND mid=11 AND versuch=1");
            Assertions.assertTrue(anzahl == 1
                , "statt 1, " + anzahl + "Datensaetze geaendert");
        } catch (SQLException e) {
            Assertions.fail("Pruefung aenderbar: "
                    + "matnr=444 AND mid=11 AND versuch=1");
        }
    }

    @Test
    public void testLetzePruefungenAendernOk2() {
        try {
            int anzahl = con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET note = 500 "
                            + "WHERE matnr=444 AND mid=12 AND versuch=2");
            Assertions.assertTrue(anzahl == 1
                , "statt 1, " + anzahl + "Datensaetze geaendert");
        } catch (SQLException e) {
            Assertions.fail("Pruefung aenderbar: "
                    + "matnr=444 AND mid=12 AND versuch=2");
        }
    }

    @Test
    public void testLetzePruefungenAendernOk3() {
        try {
            int anzahl = con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET note = 400 "
                            + "WHERE matnr=449 AND mid=11 AND versuch=3");
            Assertions.assertTrue(anzahl == 1
                , "statt 1, " + anzahl + "Datensaetze geaendert");
        } catch (SQLException e) {
            Assertions.fail("Pruefung aenderbar: "
                    + "matnr=449 AND mid=11 AND versuch=3");
        }
    }

    @Test
    public void testLetzePruefungenAendernNichtOk1() {
        try {
            con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET note = 300 "
                            + "WHERE matnr=444 AND mid=12 AND versuch=1");
            Assertions.fail("Pruefung sollte nicht aenderbar sein, da nicht letzte: "
                    + "matnr=444 AND mid=12 AND versuch=1");
        } catch (SQLException e) {
        }
    }

    @Test
    public void testLetzePruefungenAendernNichtOk2() {
        try {
            con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET note = 300 "
                            + "WHERE matnr=449 AND mid=11 AND versuch=2");
            Assertions.fail("Pruefung sollte nicht aenderbar sein, da nicht letzte: "
                    + "matnr=449 AND mid=11 AND versuch=2");
        } catch (SQLException e) {
        }
    }

    @Test
    public void testPruefungenAendernMatrikelnummerNichtOk() {
        try {
            con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET matnr = 451 "
                            + "WHERE matnr=444 AND mid=12 AND versuch=1");
            Assertions.fail("Matrikelnummer in Pruefung sollte nicht aenderbar sein");
        } catch (SQLException e) {
        }
    }

    @Test
    public void testPruefungenAendernModulIdNichtOk() {
        try {
            con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET mid = 32 "
                            + "WHERE matnr=444 AND mid=31 AND versuch=1");
            Assertions.fail("Modul-Id in Pruefung sollte nicht aenderbar sein");
        } catch (SQLException e) {
        }
    }

    @Test
    public void testPruefungenAendernDatumNichtOk() {
        try {
            con.createStatement()
                    .executeUpdate("UPDATE Pruefung "
                            + "SET datum  = to_date('11.10.15') "
                            + "WHERE matnr=444 AND mid=31 AND versuch=1");
            Assertions.fail("Datum in Pruefung sollte nicht aenderbar sein");
        } catch (SQLException e) {
        }
    }

}
